summaryrefslogtreecommitdiffstats
path: root/certmanager/lib/ui
diff options
context:
space:
mode:
Diffstat (limited to 'certmanager/lib/ui')
-rw-r--r--certmanager/lib/ui/adddirectoryservicedialogimpl.cpp6
-rw-r--r--certmanager/lib/ui/adddirectoryservicedialogimpl.h2
-rw-r--r--certmanager/lib/ui/backendconfigwidget.cpp14
-rw-r--r--certmanager/lib/ui/backendconfigwidget.h2
-rw-r--r--certmanager/lib/ui/cryptoconfigdialog.cpp4
-rw-r--r--certmanager/lib/ui/cryptoconfigdialog.h2
-rw-r--r--certmanager/lib/ui/cryptoconfigmodule.cpp8
-rw-r--r--certmanager/lib/ui/cryptoconfigmodule.h2
-rw-r--r--certmanager/lib/ui/cryptoconfigmodule_p.h18
-rw-r--r--certmanager/lib/ui/directoryserviceswidget.cpp4
-rw-r--r--certmanager/lib/ui/directoryserviceswidget.h2
-rw-r--r--certmanager/lib/ui/dnattributeorderconfigwidget.cpp4
-rw-r--r--certmanager/lib/ui/dnattributeorderconfigwidget.h4
-rw-r--r--certmanager/lib/ui/kdhorizontalline.cpp8
-rw-r--r--certmanager/lib/ui/kdhorizontalline.h4
-rw-r--r--certmanager/lib/ui/keyapprovaldialog.cpp4
-rw-r--r--certmanager/lib/ui/keyapprovaldialog.h2
-rw-r--r--certmanager/lib/ui/keylistview.cpp100
-rw-r--r--certmanager/lib/ui/keylistview.h34
-rw-r--r--certmanager/lib/ui/keyrequester.cpp28
-rw-r--r--certmanager/lib/ui/keyrequester.h12
-rw-r--r--certmanager/lib/ui/keyselectiondialog.cpp16
-rw-r--r--certmanager/lib/ui/keyselectiondialog.h6
-rw-r--r--certmanager/lib/ui/messagebox.cpp80
-rw-r--r--certmanager/lib/ui/messagebox.h40
-rw-r--r--certmanager/lib/ui/passphrasedialog.cpp4
-rw-r--r--certmanager/lib/ui/passphrasedialog.h2
-rw-r--r--certmanager/lib/ui/progressbar.cpp4
-rw-r--r--certmanager/lib/ui/progressbar.h2
29 files changed, 209 insertions, 209 deletions
diff --git a/certmanager/lib/ui/adddirectoryservicedialogimpl.h b/certmanager/lib/ui/adddirectoryservicedialogimpl.h
index d6ad086d..0b1a0ca6 100644
--- a/certmanager/lib/ui/adddirectoryservicedialogimpl.h
+++ b/certmanager/lib/ui/adddirectoryservicedialogimpl.h
@@ -40,7 +40,7 @@ class AddDirectoryServiceDialogImpl : public AddDirectoryServiceDialog
TQ_OBJECT
public:
- AddDirectoryServiceDialogImpl( TQWidget* tqparent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+ AddDirectoryServiceDialogImpl( TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
~AddDirectoryServiceDialogImpl();
};
diff --git a/certmanager/lib/ui/backendconfigwidget.h b/certmanager/lib/ui/backendconfigwidget.h
index 83b2eea0..bdac0cf0 100644
--- a/certmanager/lib/ui/backendconfigwidget.h
+++ b/certmanager/lib/ui/backendconfigwidget.h
@@ -49,7 +49,7 @@ namespace Kleo {
Q_OBJECT
TQ_OBJECT
public:
- BackendConfigWidget( CryptoBackendFactory * factory, TQWidget * tqparent=0, const char * name=0, WFlags f=0 );
+ BackendConfigWidget( CryptoBackendFactory * factory, TQWidget * parent=0, const char * name=0, WFlags f=0 );
~BackendConfigWidget();
void load();
diff --git a/certmanager/lib/ui/cryptoconfigdialog.cpp b/certmanager/lib/ui/cryptoconfigdialog.cpp
index 169af00b..65edb93e 100644
--- a/certmanager/lib/ui/cryptoconfigdialog.cpp
+++ b/certmanager/lib/ui/cryptoconfigdialog.cpp
@@ -34,11 +34,11 @@
#include <klocale.h>
#include <kaccelmanager.h>
-Kleo::CryptoConfigDialog::CryptoConfigDialog( Kleo::CryptoConfig* config, TQWidget *tqparent, const char* name )
+Kleo::CryptoConfigDialog::CryptoConfigDialog( Kleo::CryptoConfig* config, TQWidget *parent, const char* name )
: KDialogBase( Swallow,
// Remove the "whats's this" button since we have no support for it
WStyle_Customize | WStyle_DialogBorder | WStyle_Maximize | WStyle_Title | WStyle_SysMenu,
- tqparent, name, true /*modal*/,
+ parent, name, true /*modal*/,
i18n( "Configure" ), Default|Cancel|Apply|Ok|User1,
Ok, true /*separator*/, KGuiItem( i18n( "&Reset" ), "undo" ) )
{
diff --git a/certmanager/lib/ui/cryptoconfigdialog.h b/certmanager/lib/ui/cryptoconfigdialog.h
index 05bb1c39..8a4c07e9 100644
--- a/certmanager/lib/ui/cryptoconfigdialog.h
+++ b/certmanager/lib/ui/cryptoconfigdialog.h
@@ -48,7 +48,7 @@ namespace Kleo {
Q_OBJECT
TQ_OBJECT
public:
- CryptoConfigDialog( Kleo::CryptoConfig* config, TQWidget *tqparent = 0, const char* name = 0 );
+ CryptoConfigDialog( Kleo::CryptoConfig* config, TQWidget *parent = 0, const char* name = 0 );
protected:
virtual void slotOk();
diff --git a/certmanager/lib/ui/cryptoconfigmodule.cpp b/certmanager/lib/ui/cryptoconfigmodule.cpp
index 9fa55e96..a16dcd22 100644
--- a/certmanager/lib/ui/cryptoconfigmodule.cpp
+++ b/certmanager/lib/ui/cryptoconfigmodule.cpp
@@ -80,8 +80,8 @@ static const KJanusWidget::Face determineJanusFace( const Kleo::CryptoConfig * c
: KJanusWidget::IconList ;
}
-Kleo::CryptoConfigModule::CryptoConfigModule( Kleo::CryptoConfig* config, TQWidget * tqparent, const char * name )
- : KJanusWidget( tqparent, name, determineJanusFace( config ) ), mConfig( config )
+Kleo::CryptoConfigModule::CryptoConfigModule( Kleo::CryptoConfig* config, TQWidget * parent, const char * name )
+ : KJanusWidget( parent, name, determineJanusFace( config ) ), mConfig( config )
{
TQWidget * vbox = 0;
if ( face() == Plain ) {
@@ -182,8 +182,8 @@ void Kleo::CryptoConfigModule::cancel()
Kleo::CryptoConfigComponentGUI::CryptoConfigComponentGUI(
CryptoConfigModule* module, Kleo::CryptoConfigComponent* component,
- TQWidget* tqparent, const char* name )
- : TQWidget( tqparent, name ),
+ TQWidget* parent, const char* name )
+ : TQWidget( parent, name ),
mComponent( component )
{
TQGridLayout * glay = new TQGridLayout( this, 1, 3, 0, KDialog::spacingHint() );
diff --git a/certmanager/lib/ui/cryptoconfigmodule.h b/certmanager/lib/ui/cryptoconfigmodule.h
index 46606c55..b6f832b8 100644
--- a/certmanager/lib/ui/cryptoconfigmodule.h
+++ b/certmanager/lib/ui/cryptoconfigmodule.h
@@ -49,7 +49,7 @@ namespace Kleo {
Q_OBJECT
TQ_OBJECT
public:
- CryptoConfigModule( Kleo::CryptoConfig* config, TQWidget * tqparent=0, const char * name=0 );
+ CryptoConfigModule( Kleo::CryptoConfig* config, TQWidget * parent=0, const char * name=0 );
bool hasError() const;
diff --git a/certmanager/lib/ui/cryptoconfigmodule_p.h b/certmanager/lib/ui/cryptoconfigmodule_p.h
index fb9acc6c..65cae249 100644
--- a/certmanager/lib/ui/cryptoconfigmodule_p.h
+++ b/certmanager/lib/ui/cryptoconfigmodule_p.h
@@ -62,7 +62,7 @@ namespace Kleo {
public:
CryptoConfigComponentGUI( CryptoConfigModule* module, Kleo::CryptoConfigComponent* component,
- TQWidget* tqparent, const char* name = 0 );
+ TQWidget* parent, const char* name = 0 );
bool save();
void load();
@@ -82,7 +82,7 @@ namespace Kleo {
public:
CryptoConfigGroupGUI( CryptoConfigModule* module, Kleo::CryptoConfigGroup* group,
- TQGridLayout * tqlayout, TQWidget* tqparent, const char* name = 0 );
+ TQGridLayout * tqlayout, TQWidget* parent, const char* name = 0 );
bool save();
void load();
@@ -155,7 +155,7 @@ namespace Kleo {
Kleo::CryptoConfigEntry* entry,
const TQString& entryName,
TQGridLayout * tqlayout,
- TQWidget* tqparent, const char* name = 0 );
+ TQWidget* parent, const char* name = 0 );
virtual void doSave();
virtual void doLoad();
@@ -175,7 +175,7 @@ namespace Kleo {
Kleo::CryptoConfigEntry* entry,
const TQString& entryName,
TQGridLayout * tqlayout,
- TQWidget* tqparent, const char* name = 0 );
+ TQWidget* parent, const char* name = 0 );
virtual void doSave();
virtual void doLoad();
@@ -195,7 +195,7 @@ namespace Kleo {
Kleo::CryptoConfigEntry* entry,
const TQString& entryName,
TQGridLayout * tqlayout,
- TQWidget* tqparent, const char* name = 0 );
+ TQWidget* parent, const char* name = 0 );
virtual void doSave();
virtual void doLoad();
@@ -215,7 +215,7 @@ namespace Kleo {
Kleo::CryptoConfigEntry* entry,
const TQString& entryName,
TQGridLayout * tqlayout,
- TQWidget* tqparent, const char* name = 0 );
+ TQWidget* parent, const char* name = 0 );
virtual void doSave();
virtual void doLoad();
@@ -235,7 +235,7 @@ namespace Kleo {
Kleo::CryptoConfigEntry* entry,
const TQString& entryName,
TQGridLayout * tqlayout,
- TQWidget* tqparent, const char* name = 0 );
+ TQWidget* parent, const char* name = 0 );
virtual void doSave();
virtual void doLoad();
private:
@@ -255,7 +255,7 @@ namespace Kleo {
Kleo::CryptoConfigEntry* entry,
const TQString& entryName,
TQGridLayout * tqlayout,
- TQWidget* tqparent, const char* name = 0 );
+ TQWidget* parent, const char* name = 0 );
virtual void doSave();
virtual void doLoad();
private:
@@ -274,7 +274,7 @@ namespace Kleo {
Kleo::CryptoConfigEntry* entry,
const TQString& entryName,
TQGridLayout * tqlayout,
- TQWidget* tqparent, const char* name = 0 );
+ TQWidget* parent, const char* name = 0 );
virtual void doSave();
virtual void doLoad();
private slots:
diff --git a/certmanager/lib/ui/directoryserviceswidget.cpp b/certmanager/lib/ui/directoryserviceswidget.cpp
index 3dc3cd10..4975e381 100644
--- a/certmanager/lib/ui/directoryserviceswidget.cpp
+++ b/certmanager/lib/ui/directoryserviceswidget.cpp
@@ -92,8 +92,8 @@ private:
Kleo::DirectoryServicesWidget::DirectoryServicesWidget(
Kleo::CryptoConfigEntry* configEntry,
- TQWidget* tqparent, const char* name, WFlags fl )
- : DirectoryServicesWidgetBase( tqparent, name, fl ),
+ TQWidget* parent, const char* name, WFlags fl )
+ : DirectoryServicesWidgetBase( parent, name, fl ),
mConfigEntry( configEntry )
{
x500LV->setSorting( -1 );
diff --git a/certmanager/lib/ui/directoryserviceswidget.h b/certmanager/lib/ui/directoryserviceswidget.h
index 8a275f67..bfefcec8 100644
--- a/certmanager/lib/ui/directoryserviceswidget.h
+++ b/certmanager/lib/ui/directoryserviceswidget.h
@@ -49,7 +49,7 @@ class KDE_EXPORT DirectoryServicesWidget : public DirectoryServicesWidgetBase
public:
DirectoryServicesWidget(
Kleo::CryptoConfigEntry* configEntry,
- TQWidget* tqparent = 0, const char* name = 0, WFlags fl = 0 );
+ TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
~DirectoryServicesWidget();
void load();
diff --git a/certmanager/lib/ui/dnattributeorderconfigwidget.cpp b/certmanager/lib/ui/dnattributeorderconfigwidget.cpp
index 46adfe3b..a4fc7d9a 100644
--- a/certmanager/lib/ui/dnattributeorderconfigwidget.cpp
+++ b/certmanager/lib/ui/dnattributeorderconfigwidget.cpp
@@ -74,8 +74,8 @@ static void prepare( TQListView * lv ) {
lv->addColumn( i18n("Description") );
}
-Kleo::DNAttributeOrderConfigWidget::DNAttributeOrderConfigWidget( DNAttributeMapper * mapper, TQWidget * tqparent, const char * name, WFlags f )
- : TQWidget( tqparent, name, f ), d( 0 )
+Kleo::DNAttributeOrderConfigWidget::DNAttributeOrderConfigWidget( DNAttributeMapper * mapper, TQWidget * parent, const char * name, WFlags f )
+ : TQWidget( parent, name, f ), d( 0 )
{
assert( mapper );
d = new Private();
diff --git a/certmanager/lib/ui/kdhorizontalline.cpp b/certmanager/lib/ui/kdhorizontalline.cpp
index ee809df7..d736399f 100644
--- a/certmanager/lib/ui/kdhorizontalline.cpp
+++ b/certmanager/lib/ui/kdhorizontalline.cpp
@@ -48,16 +48,16 @@
#include <tqfontmetrics.h>
#include <tqapplication.h>
-KDHorizontalLine::KDHorizontalLine( TQWidget * tqparent, const char * name, WFlags f )
- : TQFrame( tqparent, name, f ),
+KDHorizontalLine::KDHorizontalLine( TQWidget * parent, const char * name, WFlags f )
+ : TQFrame( parent, name, f ),
mAlign( TQt::AlignAuto ),
mLenVisible( 0 )
{
TQFrame::setFrameStyle( HLine | Sunken );
}
-KDHorizontalLine::KDHorizontalLine( const TQString & title, TQWidget * tqparent, const char * name, WFlags f )
- : TQFrame( tqparent, name, f ),
+KDHorizontalLine::KDHorizontalLine( const TQString & title, TQWidget * parent, const char * name, WFlags f )
+ : TQFrame( parent, name, f ),
mAlign( TQt::AlignAuto ),
mLenVisible( 0 )
{
diff --git a/certmanager/lib/ui/kdhorizontalline.h b/certmanager/lib/ui/kdhorizontalline.h
index fe286801..466b54bc 100644
--- a/certmanager/lib/ui/kdhorizontalline.h
+++ b/certmanager/lib/ui/kdhorizontalline.h
@@ -49,8 +49,8 @@ class KDHorizontalLine : public TQFrame {
TQ_OBJECT
TQ_PROPERTY( TQString title READ title WRITE setTitle )
public:
- KDHorizontalLine( TQWidget * tqparent=0, const char * name=0, WFlags f=0 );
- KDHorizontalLine( const TQString & title, TQWidget * tqparent=0, const char * name=0, WFlags f=0 );
+ KDHorizontalLine( TQWidget * parent=0, const char * name=0, WFlags f=0 );
+ KDHorizontalLine( const TQString & title, TQWidget * parent=0, const char * name=0, WFlags f=0 );
~KDHorizontalLine();
TQString title() const { return mTitle; }
diff --git a/certmanager/lib/ui/keyapprovaldialog.cpp b/certmanager/lib/ui/keyapprovaldialog.cpp
index e81adc43..402235dd 100644
--- a/certmanager/lib/ui/keyapprovaldialog.cpp
+++ b/certmanager/lib/ui/keyapprovaldialog.cpp
@@ -106,9 +106,9 @@ struct Kleo::KeyApprovalDialog::Private {
Kleo::KeyApprovalDialog::KeyApprovalDialog( const std::vector<Item> & recipients,
const std::vector<GpgME::Key> & sender,
- TQWidget * tqparent, const char * name,
+ TQWidget * parent, const char * name,
bool modal )
- : KDialogBase( tqparent, name, modal, i18n("Encryption Key Approval"), Ok|Cancel, Ok ),
+ : KDialogBase( parent, name, modal, i18n("Encryption Key Approval"), Ok|Cancel, Ok ),
d( 0 )
{
assert( !recipients.empty() );
diff --git a/certmanager/lib/ui/keyapprovaldialog.h b/certmanager/lib/ui/keyapprovaldialog.h
index 993db126..0452743b 100644
--- a/certmanager/lib/ui/keyapprovaldialog.h
+++ b/certmanager/lib/ui/keyapprovaldialog.h
@@ -71,7 +71,7 @@ namespace Kleo {
KeyApprovalDialog( const std::vector<Item> & recipients,
const std::vector<GpgME::Key> & sender,
- TQWidget * tqparent=0, const char * name=0,
+ TQWidget * parent=0, const char * name=0,
bool modal=true );
~KeyApprovalDialog();
diff --git a/certmanager/lib/ui/keylistview.h b/certmanager/lib/ui/keylistview.h
index 6161bfe8..d5921131 100644
--- a/certmanager/lib/ui/keylistview.h
+++ b/certmanager/lib/ui/keylistview.h
@@ -64,10 +64,10 @@ namespace Kleo {
class KDE_EXPORT KeyListViewItem : public TQListViewItem {
public:
- KeyListViewItem( KeyListView * tqparent, const GpgME::Key & key );
- KeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::Key & key );
- KeyListViewItem( KeyListViewItem * tqparent, const GpgME::Key & key );
- KeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::Key & key );
+ KeyListViewItem( KeyListView * parent, const GpgME::Key & key );
+ KeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::Key & key );
+ KeyListViewItem( KeyListViewItem * parent, const GpgME::Key & key );
+ KeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::Key & key );
~KeyListViewItem();
void setKey( const GpgME::Key & key );
@@ -103,10 +103,10 @@ namespace Kleo {
class KDE_EXPORT SubkeyKeyListViewItem : public KeyListViewItem {
public:
- SubkeyKeyListViewItem( KeyListView * tqparent, const GpgME::Subkey & subkey );
- SubkeyKeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::Subkey & subkey );
- SubkeyKeyListViewItem( KeyListViewItem * tqparent, const GpgME::Subkey & subkey );
- SubkeyKeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::Subkey & subkey );
+ SubkeyKeyListViewItem( KeyListView * parent, const GpgME::Subkey & subkey );
+ SubkeyKeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::Subkey & subkey );
+ SubkeyKeyListViewItem( KeyListViewItem * parent, const GpgME::Subkey & subkey );
+ SubkeyKeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::Subkey & subkey );
void setSubkey( const GpgME::Subkey & subkey );
const GpgME::Subkey & subkey() const { return mSubkey; }
@@ -135,10 +135,10 @@ namespace Kleo {
class KDE_EXPORT UserIDKeyListViewItem : public KeyListViewItem {
public:
- UserIDKeyListViewItem( KeyListView * tqparent, const GpgME::UserID & userid );
- UserIDKeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::UserID & userid );
- UserIDKeyListViewItem( KeyListViewItem * tqparent, const GpgME::UserID & userid );
- UserIDKeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::UserID & userid );
+ UserIDKeyListViewItem( KeyListView * parent, const GpgME::UserID & userid );
+ UserIDKeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::UserID & userid );
+ UserIDKeyListViewItem( KeyListViewItem * parent, const GpgME::UserID & userid );
+ UserIDKeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::UserID & userid );
void setUserID( const GpgME::UserID & userid );
const GpgME::UserID userID() const { return mUserID; }
@@ -167,10 +167,10 @@ namespace Kleo {
class KDE_EXPORT SignatureKeyListViewItem : public KeyListViewItem {
public:
- SignatureKeyListViewItem( KeyListView * tqparent, const GpgME::UserID::Signature & sig );
- SignatureKeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::UserID::Signature & sig );
- SignatureKeyListViewItem( KeyListViewItem * tqparent, const GpgME::UserID::Signature & sig );
- SignatureKeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::UserID::Signature & sig );
+ SignatureKeyListViewItem( KeyListView * parent, const GpgME::UserID::Signature & sig );
+ SignatureKeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::UserID::Signature & sig );
+ SignatureKeyListViewItem( KeyListViewItem * parent, const GpgME::UserID::Signature & sig );
+ SignatureKeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::UserID::Signature & sig );
void setSignature( const GpgME::UserID::Signature & sig );
const GpgME::UserID::Signature & signature() const { return mSignature; }
@@ -254,7 +254,7 @@ namespace Kleo {
KeyListView( const ColumnStrategy * strategy,
const DisplayStrategy * display=0,
- TQWidget * tqparent=0, const char * name=0, WFlags f=0 );
+ TQWidget * parent=0, const char * name=0, WFlags f=0 );
~KeyListView();
diff --git a/certmanager/lib/ui/keyrequester.cpp b/certmanager/lib/ui/keyrequester.cpp
index 16efbd46..01e6902f 100644
--- a/certmanager/lib/ui/keyrequester.cpp
+++ b/certmanager/lib/ui/keyrequester.cpp
@@ -82,8 +82,8 @@
#include <assert.h>
Kleo::KeyRequester::KeyRequester( unsigned int allowedKeys, bool multipleKeys,
- TQWidget * tqparent, const char * name )
- : TQWidget( tqparent, name ),
+ TQWidget * parent, const char * name )
+ : TQWidget( parent, name ),
mOpenPGPBackend( 0 ),
mSMIMEBackend( 0 ),
mMulti( multipleKeys ),
@@ -94,8 +94,8 @@ Kleo::KeyRequester::KeyRequester( unsigned int allowedKeys, bool multipleKeys,
init();
}
-Kleo::KeyRequester::KeyRequester( TQWidget * tqparent, const char * name )
- : TQWidget( tqparent, name ),
+Kleo::KeyRequester::KeyRequester( TQWidget * parent, const char * name )
+ : TQWidget( parent, name ),
mOpenPGPBackend( 0 ),
mSMIMEBackend( 0 ),
mMulti( false ),
@@ -226,14 +226,14 @@ void Kleo::KeyRequester::updateKeys() {
#ifndef __KLEO_UI_SHOW_KEY_LIST_ERROR_H__
#define __KLEO_UI_SHOW_KEY_LIST_ERROR_H__
-static void showKeyListError( TQWidget * tqparent, const GpgME::Error & err ) {
+static void showKeyListError( TQWidget * parent, const GpgME::Error & err ) {
assert( err );
const TQString msg = i18n( "<qt><p>An error occurred while fetching "
"the keys from the backend:</p>"
"<p><b>%1</b></p></qt>" )
.tqarg( TQString::fromLocal8Bit( err.asString() ) );
- KMessageBox::error( tqparent, msg, i18n( "Key Listing Failed" ) );
+ KMessageBox::error( parent, msg, i18n( "Key Listing Failed" ) );
}
#endif // __KLEO_UI_SHOW_KEY_LIST_ERROR_H__
@@ -430,15 +430,15 @@ static inline unsigned int signingKeyUsage( bool openpgp, bool smime, bool trust
}
Kleo::EncryptionKeyRequester::EncryptionKeyRequester( bool multi, unsigned int proto,
- TQWidget * tqparent, const char * name,
+ TQWidget * parent, const char * name,
bool onlyTrusted, bool onlyValid )
: KeyRequester( encryptionKeyUsage( proto & OpenPGP, proto & SMIME, onlyTrusted, onlyValid ), multi,
- tqparent, name )
+ parent, name )
{
}
-Kleo::EncryptionKeyRequester::EncryptionKeyRequester( TQWidget * tqparent, const char * name )
- : KeyRequester( 0, false, tqparent, name )
+Kleo::EncryptionKeyRequester::EncryptionKeyRequester( TQWidget * parent, const char * name )
+ : KeyRequester( 0, false, parent, name )
{
}
@@ -451,15 +451,15 @@ void Kleo::EncryptionKeyRequester::setAllowedKeys( unsigned int proto, bool only
}
Kleo::SigningKeyRequester::SigningKeyRequester( bool multi, unsigned int proto,
- TQWidget * tqparent, const char * name,
+ TQWidget * parent, const char * name,
bool onlyTrusted, bool onlyValid )
: KeyRequester( signingKeyUsage( proto & OpenPGP, proto & SMIME, onlyTrusted, onlyValid ), multi,
- tqparent, name )
+ parent, name )
{
}
-Kleo::SigningKeyRequester::SigningKeyRequester( TQWidget * tqparent, const char * name )
- : KeyRequester( 0, false, tqparent, name )
+Kleo::SigningKeyRequester::SigningKeyRequester( TQWidget * parent, const char * name )
+ : KeyRequester( 0, false, parent, name )
{
}
diff --git a/certmanager/lib/ui/keyrequester.h b/certmanager/lib/ui/keyrequester.h
index 5c7913dd..68bdd703 100644
--- a/certmanager/lib/ui/keyrequester.h
+++ b/certmanager/lib/ui/keyrequester.h
@@ -78,9 +78,9 @@ namespace Kleo {
TQ_OBJECT
public:
KeyRequester( unsigned int allowedKeys, bool multipleKeys=false,
- TQWidget * tqparent=0, const char * name=0 );
+ TQWidget * parent=0, const char * name=0 );
// Constructor for TQt Designer
- KeyRequester( TQWidget * tqparent=0, const char * name=0 );
+ KeyRequester( TQWidget * parent=0, const char * name=0 );
~KeyRequester();
const GpgME::Key & key() const;
@@ -169,12 +169,12 @@ namespace Kleo {
* Preferred constructor
*/
EncryptionKeyRequester( bool multipleKeys=false, unsigned int proto=AllProtocols,
- TQWidget * tqparent=0, const char * name=0,
+ TQWidget * parent=0, const char * name=0,
bool onlyTrusted=true, bool onlyValid=true );
/**
* Constructor for TQt designer
*/
- EncryptionKeyRequester( TQWidget * tqparent=0, const char * name=0 );
+ EncryptionKeyRequester( TQWidget * parent=0, const char * name=0 );
~EncryptionKeyRequester();
void setAllowedKeys( unsigned int proto, bool onlyTrusted=true, bool onlyValid=true );
@@ -202,12 +202,12 @@ namespace Kleo {
* @param onlyValid only show valid keys
*/
SigningKeyRequester( bool multipleKeys=false, unsigned int proto=AllProtocols,
- TQWidget * tqparent=0, const char * name=0,
+ TQWidget * parent=0, const char * name=0,
bool onlyTrusted=true, bool onlyValid=true );
/**
* Constructor for TQt designer
*/
- SigningKeyRequester( TQWidget * tqparent=0, const char * name=0 );
+ SigningKeyRequester( TQWidget * parent=0, const char * name=0 );
~SigningKeyRequester();
/*
diff --git a/certmanager/lib/ui/keyselectiondialog.cpp b/certmanager/lib/ui/keyselectiondialog.cpp
index 141e9e98..29d24e15 100644
--- a/certmanager/lib/ui/keyselectiondialog.cpp
+++ b/certmanager/lib/ui/keyselectiondialog.cpp
@@ -301,9 +301,9 @@ Kleo::KeySelectionDialog::KeySelectionDialog( const TQString & title,
unsigned int keyUsage,
bool extendedSelection,
bool rememberChoice,
- TQWidget * tqparent, const char * name,
+ TQWidget * parent, const char * name,
bool modal )
- : KDialogBase( tqparent, name, modal, title, Default|Ok|Cancel|Help, Ok ),
+ : KDialogBase( parent, name, modal, title, Default|Ok|Cancel|Help, Ok ),
mOpenPGPBackend( 0 ),
mSMIMEBackend( 0 ),
mRememberCB( 0 ),
@@ -321,9 +321,9 @@ Kleo::KeySelectionDialog::KeySelectionDialog( const TQString & title,
unsigned int keyUsage,
bool extendedSelection,
bool rememberChoice,
- TQWidget * tqparent, const char * name,
+ TQWidget * parent, const char * name,
bool modal )
- : KDialogBase( tqparent, name, modal, title, Default|Ok|Cancel|Help, Ok ),
+ : KDialogBase( parent, name, modal, title, Default|Ok|Cancel|Help, Ok ),
mOpenPGPBackend( 0 ),
mSMIMEBackend( 0 ),
mRememberCB( 0 ),
@@ -342,9 +342,9 @@ Kleo::KeySelectionDialog::KeySelectionDialog( const TQString & title,
unsigned int keyUsage,
bool extendedSelection,
bool rememberChoice,
- TQWidget * tqparent, const char * name,
+ TQWidget * parent, const char * name,
bool modal )
- : KDialogBase( tqparent, name, modal, title, Default|Ok|Cancel|Help, Ok ),
+ : KDialogBase( parent, name, modal, title, Default|Ok|Cancel|Help, Ok ),
mOpenPGPBackend( 0 ),
mSMIMEBackend( 0 ),
mRememberCB( 0 ),
@@ -562,14 +562,14 @@ void Kleo::KeySelectionDialog::slotStartCertificateManager( const TQString &quer
#ifndef __KLEO_UI_SHOW_KEY_LIST_ERROR_H__
#define __KLEO_UI_SHOW_KEY_LIST_ERROR_H__
-static void showKeyListError( TQWidget * tqparent, const GpgME::Error & err ) {
+static void showKeyListError( TQWidget * parent, const GpgME::Error & err ) {
assert( err );
const TQString msg = i18n( "<qt><p>An error occurred while fetching "
"the keys from the backend:</p>"
"<p><b>%1</b></p></qt>" )
.tqarg( TQString::fromLocal8Bit( err.asString() ) );
- KMessageBox::error( tqparent, msg, i18n( "Key Listing Failed" ) );
+ KMessageBox::error( parent, msg, i18n( "Key Listing Failed" ) );
}
#endif // __KLEO_UI_SHOW_KEY_LIST_ERROR_H__
diff --git a/certmanager/lib/ui/keyselectiondialog.h b/certmanager/lib/ui/keyselectiondialog.h
index c0bfa7ee..44634a39 100644
--- a/certmanager/lib/ui/keyselectiondialog.h
+++ b/certmanager/lib/ui/keyselectiondialog.h
@@ -90,7 +90,7 @@ namespace Kleo {
unsigned int keyUsage=AllKeys,
bool extendedSelection=false,
bool rememberChoice=false,
- TQWidget * tqparent=0, const char * name=0,
+ TQWidget * parent=0, const char * name=0,
bool modal=true );
KeySelectionDialog( const TQString & title,
const TQString & text,
@@ -99,7 +99,7 @@ namespace Kleo {
unsigned int keyUsage=AllKeys,
bool extendedSelection=false,
bool rememberChoice=false,
- TQWidget * tqparent=0, const char * name=0,
+ TQWidget * parent=0, const char * name=0,
bool modal=true );
KeySelectionDialog( const TQString & title,
const TQString & text,
@@ -107,7 +107,7 @@ namespace Kleo {
unsigned int keyUsage=AllKeys,
bool extendedSelection=false,
bool rememberChoice=false,
- TQWidget * tqparent=0, const char * name=0,
+ TQWidget * parent=0, const char * name=0,
bool modal=true );
~KeySelectionDialog();
diff --git a/certmanager/lib/ui/messagebox.cpp b/certmanager/lib/ui/messagebox.cpp
index 0cef145b..2dfe083d 100644
--- a/certmanager/lib/ui/messagebox.cpp
+++ b/certmanager/lib/ui/messagebox.cpp
@@ -77,8 +77,8 @@ class AuditLogViewer : public KDialogBase {
// Q_OBJECT
TQ_OBJECT
public:
- explicit AuditLogViewer( const TQString & log, TQWidget * tqparent=0, const char * name=0, WFlags f=0 )
- : KDialogBase( tqparent, name, false, i18n("View GnuPG Audit Log"),
+ explicit AuditLogViewer( const TQString & log, TQWidget * parent=0, const char * name=0, WFlags f=0 )
+ : KDialogBase( parent, name, false, i18n("View GnuPG Audit Log"),
Close|User1|User2, Close, false, KGuiItem_save(), KGuiItem_copy() ),
m_log( /* sic */ ),
m_textEdit( new TQTextEdit( this, "m_textEdit" ) )
@@ -144,13 +144,13 @@ private:
} // anon namespace
// static
-void MessageBox::auditLog( TQWidget * tqparent, const Job * job, const TQString & caption ) {
+void MessageBox::auditLog( TQWidget * parent, const Job * job, const TQString & caption ) {
if ( !job )
return;
if ( !GpgME::hasFeature( AuditLogFeature ) || !job->isAuditLogSupported() ) {
- KMessageBox::information( tqparent, i18n("Your system does not have support for GnuPG Audit Logs"),
+ KMessageBox::information( parent, i18n("Your system does not have support for GnuPG Audit Logs"),
i18n("System Error") );
return;
}
@@ -158,7 +158,7 @@ void MessageBox::auditLog( TQWidget * tqparent, const Job * job, const TQString
const GpgME::Error err = job->auditLogError();
if ( err.code() != GPG_ERR_NO_DATA ) {
- KMessageBox::information( tqparent, i18n("An error occurred while trying to retrieve the GnuPG Audit Log:\n%1")
+ KMessageBox::information( parent, i18n("An error occurred while trying to retrieve the GnuPG Audit Log:\n%1")
.tqarg( TQString::fromLocal8Bit( err.asString() ) ),
i18n("GnuPG Audit Log Error") );
return;
@@ -167,29 +167,29 @@ void MessageBox::auditLog( TQWidget * tqparent, const Job * job, const TQString
const TQString log = job->auditLogAsHtml();
if ( log.isEmpty() ) {
- KMessageBox::information( tqparent, i18n("No GnuPG Audit Log available for this operation."),
+ KMessageBox::information( parent, i18n("No GnuPG Audit Log available for this operation."),
i18n("No GnuPG Audit Log") );
return;
}
- auditLog( tqparent, log, caption );
+ auditLog( parent, log, caption );
}
// static
-void MessageBox::auditLog( TQWidget * tqparent, const TQString & log, const TQString & caption ) {
- AuditLogViewer * const alv = new AuditLogViewer( log, tqparent, "alv", TQt::WDestructiveClose );
+void MessageBox::auditLog( TQWidget * parent, const TQString & log, const TQString & caption ) {
+ AuditLogViewer * const alv = new AuditLogViewer( log, parent, "alv", TQt::WDestructiveClose );
alv->setCaption( caption );
alv->show();
}
// static
-void MessageBox::auditLog( TQWidget * tqparent, const Job * job ) {
- auditLog( tqparent, job, i18n("GnuPG Audit Log Viewer") );
+void MessageBox::auditLog( TQWidget * parent, const Job * job ) {
+ auditLog( parent, job, i18n("GnuPG Audit Log Viewer") );
}
// static
-void MessageBox::auditLog( TQWidget * tqparent, const TQString & log ) {
- auditLog( tqparent, log, i18n("GnuPG Audit Log Viewer") );
+void MessageBox::auditLog( TQWidget * parent, const TQString & log ) {
+ auditLog( parent, log, i18n("GnuPG Audit Log Viewer") );
}
static TQString to_information_string( const SigningResult & result ) {
@@ -221,63 +221,63 @@ static TQString to_error_string( const SigningResult & sresult, const Encryption
}
// static
-void MessageBox::information( TQWidget * tqparent, const SigningResult & result, const Job * job, int options ) {
- information( tqparent, result, job, i18n("Signing Result"), options );
+void MessageBox::information( TQWidget * parent, const SigningResult & result, const Job * job, int options ) {
+ information( parent, result, job, i18n("Signing Result"), options );
}
// static
-void MessageBox::information( TQWidget * tqparent, const SigningResult & result, const Job * job, const TQString & caption, int options ) {
- make( tqparent, TQMessageBox::Information, to_information_string( result ), job, caption, options );
+void MessageBox::information( TQWidget * parent, const SigningResult & result, const Job * job, const TQString & caption, int options ) {
+ make( parent, TQMessageBox::Information, to_information_string( result ), job, caption, options );
}
// static
-void MessageBox::error( TQWidget * tqparent, const SigningResult & result, const Job * job, int options ) {
- error( tqparent, result, job, i18n("Signing Error"), options );
+void MessageBox::error( TQWidget * parent, const SigningResult & result, const Job * job, int options ) {
+ error( parent, result, job, i18n("Signing Error"), options );
}
// static
-void MessageBox::error( TQWidget * tqparent, const SigningResult & result, const Job * job, const TQString & caption, int options ) {
- make( tqparent, TQMessageBox::Critical, to_error_string( result ), job, caption, options );
+void MessageBox::error( TQWidget * parent, const SigningResult & result, const Job * job, const TQString & caption, int options ) {
+ make( parent, TQMessageBox::Critical, to_error_string( result ), job, caption, options );
}
// static
-void MessageBox::information( TQWidget * tqparent, const EncryptionResult & result, const Job * job, int options ) {
- information( tqparent, result, job, i18n("Encryption Result"), options );
+void MessageBox::information( TQWidget * parent, const EncryptionResult & result, const Job * job, int options ) {
+ information( parent, result, job, i18n("Encryption Result"), options );
}
// static
-void MessageBox::information( TQWidget * tqparent, const EncryptionResult & result, const Job * job, const TQString & caption, int options ) {
- make( tqparent, TQMessageBox::Information, to_information_string( result ), job, caption, options );
+void MessageBox::information( TQWidget * parent, const EncryptionResult & result, const Job * job, const TQString & caption, int options ) {
+ make( parent, TQMessageBox::Information, to_information_string( result ), job, caption, options );
}
// static
-void MessageBox::error( TQWidget * tqparent, const EncryptionResult & result, const Job * job, int options ) {
- error( tqparent, result, job, i18n("Encryption Error"), options );
+void MessageBox::error( TQWidget * parent, const EncryptionResult & result, const Job * job, int options ) {
+ error( parent, result, job, i18n("Encryption Error"), options );
}
// static
-void MessageBox::error( TQWidget * tqparent, const EncryptionResult & result, const Job * job, const TQString & caption, int options ) {
- make( tqparent, TQMessageBox::Critical, to_error_string( result ), job, caption, options );
+void MessageBox::error( TQWidget * parent, const EncryptionResult & result, const Job * job, const TQString & caption, int options ) {
+ make( parent, TQMessageBox::Critical, to_error_string( result ), job, caption, options );
}
// static
-void MessageBox::information( TQWidget * tqparent, const SigningResult & sresult, const EncryptionResult & eresult, const Job * job, int options ) {
- information( tqparent, sresult, eresult, job, i18n("Encryption Result"), options );
+void MessageBox::information( TQWidget * parent, const SigningResult & sresult, const EncryptionResult & eresult, const Job * job, int options ) {
+ information( parent, sresult, eresult, job, i18n("Encryption Result"), options );
}
// static
-void MessageBox::information( TQWidget * tqparent, const SigningResult & sresult, const EncryptionResult & eresult, const Job * job, const TQString & caption, int options ) {
- make( tqparent, TQMessageBox::Information, to_information_string( sresult, eresult ), job, caption, options );
+void MessageBox::information( TQWidget * parent, const SigningResult & sresult, const EncryptionResult & eresult, const Job * job, const TQString & caption, int options ) {
+ make( parent, TQMessageBox::Information, to_information_string( sresult, eresult ), job, caption, options );
}
// static
-void MessageBox::error( TQWidget * tqparent, const SigningResult & sresult, const EncryptionResult & eresult, const Job * job, int options ) {
- error( tqparent, sresult, eresult, job, i18n("Encryption Error"), options );
+void MessageBox::error( TQWidget * parent, const SigningResult & sresult, const EncryptionResult & eresult, const Job * job, int options ) {
+ error( parent, sresult, eresult, job, i18n("Encryption Error"), options );
}
// static
-void MessageBox::error( TQWidget * tqparent, const SigningResult & sresult, const EncryptionResult & eresult, const Job * job, const TQString & caption, int options ) {
- make( tqparent, TQMessageBox::Critical, to_error_string( sresult, eresult ), job, caption, options );
+void MessageBox::error( TQWidget * parent, const SigningResult & sresult, const EncryptionResult & eresult, const Job * job, const TQString & caption, int options ) {
+ make( parent, TQMessageBox::Critical, to_error_string( sresult, eresult ), job, caption, options );
}
// static
@@ -307,15 +307,15 @@ bool MessageBox::showAuditLogButton( const Kleo::Job * job ) {
// static
-void MessageBox::make( TQWidget * tqparent, TQMessageBox::Icon icon, const TQString & text, const Job * job, const TQString & caption, int options ) {
+void MessageBox::make( TQWidget * parent, TQMessageBox::Icon icon, const TQString & text, const Job * job, const TQString & caption, int options ) {
KDialogBase * dialog = showAuditLogButton( job )
? new KDialogBase( caption, KDialogBase::Yes | KDialogBase::No,
KDialogBase::Yes, KDialogBase::Yes,
- tqparent, "error", true, true,
+ parent, "error", true, true,
KStdGuiItem::ok(), KGuiItem_showAuditLog() )
: new KDialogBase( caption, KDialogBase::Yes,
KDialogBase::Yes, KDialogBase::Yes,
- tqparent, "error", true, true,
+ parent, "error", true, true,
KStdGuiItem::ok() ) ;
if ( options & KMessageBox::PlainCaption )
dialog->setPlainCaption( caption );
diff --git a/certmanager/lib/ui/messagebox.h b/certmanager/lib/ui/messagebox.h
index 64cd1a2e..69dea34c 100644
--- a/certmanager/lib/ui/messagebox.h
+++ b/certmanager/lib/ui/messagebox.h
@@ -54,30 +54,30 @@ namespace Kleo {
class MessageBox {
public:
- static void information( TQWidget * tqparent, const GpgME::SigningResult & result, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
- static void information( TQWidget * tqparent, const GpgME::SigningResult & result, const Kleo::Job * job, int options=KMessageBox::Notify );
- static void error( TQWidget * tqparent, const GpgME::SigningResult & result, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
- static void error( TQWidget * tqparent, const GpgME::SigningResult & result, const Kleo::Job * job, int options=KMessageBox::Notify );
-
- static void information( TQWidget * tqparent, const GpgME::EncryptionResult & result, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
- static void information( TQWidget * tqparent, const GpgME::EncryptionResult & result, const Kleo::Job * job, int options=KMessageBox::Notify );
- static void error( TQWidget * tqparent, const GpgME::EncryptionResult & result, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
- static void error( TQWidget * tqparent, const GpgME::EncryptionResult & result, const Kleo::Job * job, int options=KMessageBox::Notify );
-
- static void information( TQWidget * tqparent, const GpgME::SigningResult & sresult, const GpgME::EncryptionResult & eresult, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
- static void information( TQWidget * tqparent, const GpgME::SigningResult & sresult, const GpgME::EncryptionResult & eresult, const Kleo::Job * job, int options=KMessageBox::Notify );
- static void error( TQWidget * tqparent, const GpgME::SigningResult & sresult, const GpgME::EncryptionResult & eresult, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
- static void error( TQWidget * tqparent, const GpgME::SigningResult & sresult, const GpgME::EncryptionResult & eresult, const Kleo::Job * job, int options=KMessageBox::Notify );
-
- static void auditLog( TQWidget * tqparent, const Kleo::Job * job, const TQString & caption );
- static void auditLog( TQWidget * tqparent, const Kleo::Job * job );
- static void auditLog( TQWidget * tqparent, const TQString & log, const TQString & caption );
- static void auditLog( TQWidget * tqparent, const TQString & log );
+ static void information( TQWidget * parent, const GpgME::SigningResult & result, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
+ static void information( TQWidget * parent, const GpgME::SigningResult & result, const Kleo::Job * job, int options=KMessageBox::Notify );
+ static void error( TQWidget * parent, const GpgME::SigningResult & result, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
+ static void error( TQWidget * parent, const GpgME::SigningResult & result, const Kleo::Job * job, int options=KMessageBox::Notify );
+
+ static void information( TQWidget * parent, const GpgME::EncryptionResult & result, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
+ static void information( TQWidget * parent, const GpgME::EncryptionResult & result, const Kleo::Job * job, int options=KMessageBox::Notify );
+ static void error( TQWidget * parent, const GpgME::EncryptionResult & result, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
+ static void error( TQWidget * parent, const GpgME::EncryptionResult & result, const Kleo::Job * job, int options=KMessageBox::Notify );
+
+ static void information( TQWidget * parent, const GpgME::SigningResult & sresult, const GpgME::EncryptionResult & eresult, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
+ static void information( TQWidget * parent, const GpgME::SigningResult & sresult, const GpgME::EncryptionResult & eresult, const Kleo::Job * job, int options=KMessageBox::Notify );
+ static void error( TQWidget * parent, const GpgME::SigningResult & sresult, const GpgME::EncryptionResult & eresult, const Kleo::Job * job, const TQString & caption, int options=KMessageBox::Notify );
+ static void error( TQWidget * parent, const GpgME::SigningResult & sresult, const GpgME::EncryptionResult & eresult, const Kleo::Job * job, int options=KMessageBox::Notify );
+
+ static void auditLog( TQWidget * parent, const Kleo::Job * job, const TQString & caption );
+ static void auditLog( TQWidget * parent, const Kleo::Job * job );
+ static void auditLog( TQWidget * parent, const TQString & log, const TQString & caption );
+ static void auditLog( TQWidget * parent, const TQString & log );
static bool showAuditLogButton( const Kleo::Job * job );
private:
- static void make( TQWidget * tqparent, TQMessageBox::Icon icon, const TQString & text, const Kleo::Job * job, const TQString & caption, int options );
+ static void make( TQWidget * parent, TQMessageBox::Icon icon, const TQString & text, const Kleo::Job * job, const TQString & caption, int options );
};
diff --git a/certmanager/lib/ui/passphrasedialog.cpp b/certmanager/lib/ui/passphrasedialog.cpp
index 91ecdef6..d8827887 100644
--- a/certmanager/lib/ui/passphrasedialog.cpp
+++ b/certmanager/lib/ui/passphrasedialog.cpp
@@ -66,8 +66,8 @@ struct Kleo::PassphraseDialog::Private {
Kleo::PassphraseDialog::PassphraseDialog( const TQString & msg, const TQString & caption,
- TQWidget * tqparent, const char * name, bool modal )
- : KDialogBase( tqparent, name, modal, caption, Ok|Cancel, Ok ), d( 0 )
+ TQWidget * parent, const char * name, bool modal )
+ : KDialogBase( parent, name, modal, caption, Ok|Cancel, Ok ), d( 0 )
{
d = new Private();
diff --git a/certmanager/lib/ui/passphrasedialog.h b/certmanager/lib/ui/passphrasedialog.h
index 6ff4289c..15e6c132 100644
--- a/certmanager/lib/ui/passphrasedialog.h
+++ b/certmanager/lib/ui/passphrasedialog.h
@@ -59,7 +59,7 @@ namespace Kleo {
public:
PassphraseDialog( const TQString & description,
const TQString & caption=TQString(),
- TQWidget * tqparent=0, const char * name=0,
+ TQWidget * parent=0, const char * name=0,
bool modal=true );
~PassphraseDialog();
diff --git a/certmanager/lib/ui/progressbar.cpp b/certmanager/lib/ui/progressbar.cpp
index b6518c60..6fe2f531 100644
--- a/certmanager/lib/ui/progressbar.cpp
+++ b/certmanager/lib/ui/progressbar.cpp
@@ -39,8 +39,8 @@
static const int busyTimerTickInterval = 100;
static const int busyTimerTickIncrement = 5;
-Kleo::ProgressBar::ProgressBar( TQWidget * tqparent, const char * name, WFlags f )
- : TQProgressBar( 0, tqparent, name, f ),
+Kleo::ProgressBar::ProgressBar( TQWidget * parent, const char * name, WFlags f )
+ : TQProgressBar( 0, parent, name, f ),
mRealProgress( -1 )
{
mBusyTimer = new TQTimer( this );
diff --git a/certmanager/lib/ui/progressbar.h b/certmanager/lib/ui/progressbar.h
index 705fe11f..f5a9644f 100644
--- a/certmanager/lib/ui/progressbar.h
+++ b/certmanager/lib/ui/progressbar.h
@@ -46,7 +46,7 @@ namespace Kleo {
Q_OBJECT
TQ_OBJECT
public:
- ProgressBar( TQWidget * tqparent=0, const char * name=0, WFlags f=0 );
+ ProgressBar( TQWidget * parent=0, const char * name=0, WFlags f=0 );
public slots:
void slotProgress( const TQString & message, int type, int current, int total );
diff --git a/certmanager/lib/ui/adddirectoryservicedialogimpl.cpp b/certmanager/lib/ui/adddirectoryservicedialogimpl.cpp
index a8d48a00..1c548c5b 100644
--- a/certmanager/lib/ui/adddirectoryservicedialogimpl.cpp
+++ b/certmanager/lib/ui/adddirectoryservicedialogimpl.cpp
@@ -40,14 +40,14 @@
#include <klineedit.h>
/*
* Constructs a AddDirectoryServiceDialogImpl which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-AddDirectoryServiceDialogImpl::AddDirectoryServiceDialogImpl( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : AddDirectoryServiceDialog( tqparent, name, modal, fl )
+AddDirectoryServiceDialogImpl::AddDirectoryServiceDialogImpl( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : AddDirectoryServiceDialog( parent, name, modal, fl )
{
portED->setValidator( new TQIntValidator( 0, 65535, TQT_TQOBJECT(portED) ) );
}
@@ -40,14 +40,14 @@
#include <klineedit.h>
/*
- * Constructs a AddDirectoryServiceDialogImpl which is a child of 'tqparent', with the
+ * Constructs a AddDirectoryServiceDialogImpl which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
diff --git a/certmanager/lib/ui/backendconfigwidget.cpp b/certmanager/lib/ui/backendconfigwidget.cpp
index 7869b1d2..1052cff5 100644
--- a/certmanager/lib/ui/backendconfigwidget.cpp
+++ b/certmanager/lib/ui/backendconfigwidget.cpp
@@ -76,8 +76,8 @@ namespace Kleo {
class Kleo::BackendListView : public KListView
{
public:
- BackendListView( BackendConfigWidget* tqparent, const char* name = 0 )
- : KListView( tqparent, name ) {}
+ BackendListView( BackendConfigWidget* parent, const char* name = 0 )
+ : KListView( parent, name ) {}
/// return backend for currently selected (/current) item. Used by Configure button.
const Kleo::CryptoBackend* currentBackend() const;
@@ -162,7 +162,7 @@ const Kleo::CryptoBackend* Kleo::BackendListView::currentBackend() const {
if ( !curItem ) // can't happen
return 0;
if ( lvi_cast<Kleo::ProtocolCheckListItem>( curItem ) )
- curItem = curItem->tqparent();
+ curItem = curItem->parent();
if ( const Kleo::BackendListViewItem * blvi = lvi_cast<Kleo::BackendListViewItem>( curItem ) )
return blvi->cryptoBackend();
return 0;
@@ -175,9 +175,9 @@ const Kleo::CryptoBackend* Kleo::BackendListView::chosenBackend( const char * pr
it.current() ; ++it )
if ( ProtocolCheckListItem * p = lvi_cast<ProtocolCheckListItem>( it.current() ) )
if ( p->isOn() && qstricmp( p->protocolName(), protocolName ) == 0 ) {
// OK that's the one. Now go up to the tqparent backend
// (need to do that in the listview since Protocol doesn't know it)
- if ( const BackendListViewItem * parItem = lvi_cast<BackendListViewItem>( it.current()->tqparent() ) )
+ if ( const BackendListViewItem * parItem = lvi_cast<BackendListViewItem>( it.current()->parent() ) )
return parItem->cryptoBackend();
}
return 0;
@@ -196,8 +196,8 @@ void Kleo::BackendListView::deselectAll( const char * protocolName, TQCheckListI
////
-Kleo::BackendConfigWidget::BackendConfigWidget( CryptoBackendFactory * factory, TQWidget * tqparent, const char * name, WFlags f )
- : TQWidget( tqparent, name, f ), d( 0 )
+Kleo::BackendConfigWidget::BackendConfigWidget( CryptoBackendFactory * factory, TQWidget * parent, const char * name, WFlags f )
+ : TQWidget( parent, name, f ), d( 0 )
{
assert( factory );
d = new Private();
@@ -175,9 +175,9 @@ const Kleo::CryptoBackend* Kleo::BackendListView::chosenBackend( const char * pr
if ( ProtocolCheckListItem * p = lvi_cast<ProtocolCheckListItem>( it.current() ) )
if ( p->isOn() && qstricmp( p->protocolName(), protocolName ) == 0 ) {
- // OK that's the one. Now go up to the tqparent backend
+ // OK that's the one. Now go up to the parent backend
// (need to do that in the listview since Protocol doesn't know it)
diff --git a/certmanager/lib/ui/dnattributeorderconfigwidget.h b/certmanager/lib/ui/dnattributeorderconfigwidget.h
index a0867c4f..b433c35b 100644
--- a/certmanager/lib/ui/dnattributeorderconfigwidget.h
+++ b/certmanager/lib/ui/dnattributeorderconfigwidget.h
@@ -47,8 +47,8 @@ namespace Kleo {
Q_OBJECT
TQ_OBJECT
public:
- /*! Use Kleo::DNAttributeMapper::instance()->configWidget( tqparent, name ) instead. */
- DNAttributeOrderConfigWidget( DNAttributeMapper * mapper, TQWidget * tqparent=0, const char * name=0, WFlags f=0 );
+ /*! Use Kleo::DNAttributeMapper::instance()->configWidget( parent, name ) instead. */
+ DNAttributeOrderConfigWidget( DNAttributeMapper * mapper, TQWidget * parent=0, const char * name=0, WFlags f=0 );
~DNAttributeOrderConfigWidget();
void load();
diff --git a/certmanager/lib/ui/keylistview.cpp b/certmanager/lib/ui/keylistview.cpp
index f1641339..32d5be21 100644
--- a/certmanager/lib/ui/keylistview.cpp
+++ b/certmanager/lib/ui/keylistview.cpp
@@ -63,15 +63,15 @@ namespace {
class ItemToolTip : public TQToolTip {
public:
- ItemToolTip( Kleo::KeyListView * tqparent );
+ ItemToolTip( Kleo::KeyListView * parent );
protected:
void maybeTip( const TQPoint & p );
private:
Kleo::KeyListView * mKeyListView;
};
- ItemToolTip::ItemToolTip( Kleo::KeyListView * tqparent )
- : TQToolTip( tqparent->viewport() ), mKeyListView( tqparent ) {}
+ ItemToolTip::ItemToolTip( Kleo::KeyListView * parent )
+ : TQToolTip( parent->viewport() ), mKeyListView( parent ) {}
void ItemToolTip::maybeTip( const TQPoint & p ) {
if ( !mKeyListView )
@@ -135,8 +135,8 @@ static const struct {
static const int numSignalReplacements = sizeof signalReplacements / sizeof *signalReplacements;
-Kleo::KeyListView::KeyListView( const ColumnStrategy * columnStrategy, const DisplayStrategy * displayStrategy, TQWidget * tqparent, const char * name, WFlags f )
- : KListView( tqparent, name ),
+Kleo::KeyListView::KeyListView( const ColumnStrategy * columnStrategy, const DisplayStrategy * displayStrategy, TQWidget * parent, const char * name, WFlags f )
+ : KListView( parent, name ),
mColumnStrategy( columnStrategy ),
mDisplayStrategy ( displayStrategy ),
mHierarchical( false )
@@ -276,9 +276,9 @@ void Kleo::KeyListView::doHierarchicalInsert( const GpgME::Key & key ) {
return;
KeyListViewItem * item = 0;
if ( !key.isRoot() )
- if ( KeyListViewItem * tqparent = itemByFingerprint( key.chainID() ) ) {
- item = new KeyListViewItem( tqparent, key );
- tqparent->setOpen( true );
+ if ( KeyListViewItem * parent = itemByFingerprint( key.chainID() ) ) {
+ item = new KeyListViewItem( parent, key );
+ parent->setOpen( true );
}
if ( !item )
item = new KeyListViewItem( this, key ); // top-level (for now)
@@ -293,12 +293,12 @@ void Kleo::KeyListView::gatherScattered() {
item = item->nextSibling();
if ( cur->key().isRoot() )
continue;
- if ( KeyListViewItem * tqparent = itemByFingerprint( cur->key().chainID() ) ) {
- // found a new tqparent...
+ if ( KeyListViewItem * parent = itemByFingerprint( cur->key().chainID() ) ) {
+ // found a new parent...
// ### todo: optimize by suppressing removing/adding the item to the itemMap...
takeItem( cur );
- tqparent->insertItem( cur );
- tqparent->setOpen( true );
+ parent->insertItem( cur );
+ parent->setOpen( true );
}
}
}
@@ -313,8 +313,8 @@ void Kleo::KeyListView::scatterGathered( TQListViewItem * start ) {
assert( cur->childCount() == 0 );
// ### todo: optimize by suppressing removing/adding the item to the itemMap...
- if ( cur->tqparent() )
- cur->tqparent()->takeItem( cur );
+ if ( cur->parent() )
+ cur->parent()->takeItem( cur );
else
takeItem( cur );
insertItem( cur );
@@ -370,26 +370,26 @@ void Kleo::KeyListView::slotEmitContextMenu( KListView*, TQListViewItem * item,
//
//
-Kleo::KeyListViewItem::KeyListViewItem( KeyListView * tqparent, const GpgME::Key & key )
- : TQListViewItem( tqparent )
+Kleo::KeyListViewItem::KeyListViewItem( KeyListView * parent, const GpgME::Key & key )
+ : TQListViewItem( parent )
{
setKey( key );
}
-Kleo::KeyListViewItem::KeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::Key & key )
- : TQListViewItem( tqparent, after )
+Kleo::KeyListViewItem::KeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::Key & key )
+ : TQListViewItem( parent, after )
{
setKey( key );
}
-Kleo::KeyListViewItem::KeyListViewItem( KeyListViewItem * tqparent, const GpgME::Key & key )
- : TQListViewItem( tqparent )
+Kleo::KeyListViewItem::KeyListViewItem( KeyListViewItem * parent, const GpgME::Key & key )
+ : TQListViewItem( parent )
{
setKey( key );
}
-Kleo::KeyListViewItem::KeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::Key & key )
- : TQListViewItem( tqparent, after )
+Kleo::KeyListViewItem::KeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::Key & key )
+ : TQListViewItem( parent, after )
{
setKey( key );
}
@@ -402,7 +402,7 @@ Kleo::KeyListViewItem::~KeyListViewItem() {
while ( TQListViewItem * item = firstChild() )
delete item;
// better do this here, too, since deletion is top-down and thus
// we're deleted when our tqparent item is no longer a
// KeyListViewItem, but a mere TQListViewItem, so our takeItem()
// overload is gone by that time...
if ( KeyListView * lv = listView() )
@@ -483,33 +483,33 @@ void Kleo::KeyListViewItem::takeItem( TQListViewItem * qlvi ) {
//
//
-Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListView * tqparent, const GpgME::Subkey & subkey )
- : KeyListViewItem( tqparent, subkey.tqparent() ), mSubkey( subkey )
+Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListView * parent, const GpgME::Subkey & subkey )
+ : KeyListViewItem( parent, subkey.parent() ), mSubkey( subkey )
{
}
-Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::Subkey & subkey )
- : KeyListViewItem( tqparent, after, subkey.tqparent() ), mSubkey( subkey )
+Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::Subkey & subkey )
+ : KeyListViewItem( parent, after, subkey.parent() ), mSubkey( subkey )
{
}
-Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListViewItem * tqparent, const GpgME::Subkey & subkey )
- : KeyListViewItem( tqparent, subkey.tqparent() ), mSubkey( subkey )
+Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListViewItem * parent, const GpgME::Subkey & subkey )
+ : KeyListViewItem( parent, subkey.parent() ), mSubkey( subkey )
{
}
-Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::Subkey & subkey )
- : KeyListViewItem( tqparent, after, subkey.tqparent() ), mSubkey( subkey )
+Kleo::SubkeyKeyListViewItem::SubkeyKeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::Subkey & subkey )
+ : KeyListViewItem( parent, after, subkey.parent() ), mSubkey( subkey )
{
}
void Kleo::SubkeyKeyListViewItem::setSubkey( const GpgME::Subkey & subkey ) {
mSubkey = subkey;
- setKey( subkey.tqparent() );
+ setKey( subkey.parent() );
}
TQString Kleo::SubkeyKeyListViewItem::text( int col ) const {
@@ -561,33 +561,33 @@ void Kleo::SubkeyKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup &
//
//
-Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListView * tqparent, const GpgME::UserID & userID )
- : KeyListViewItem( tqparent, userID.tqparent() ), mUserID( userID )
+Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListView * parent, const GpgME::UserID & userID )
+ : KeyListViewItem( parent, userID.parent() ), mUserID( userID )
{
}
-Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::UserID & userID )
- : KeyListViewItem( tqparent, after, userID.tqparent() ), mUserID( userID )
+Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::UserID & userID )
+ : KeyListViewItem( parent, after, userID.parent() ), mUserID( userID )
{
}
-Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListViewItem * tqparent, const GpgME::UserID & userID )
- : KeyListViewItem( tqparent, userID.tqparent() ), mUserID( userID )
+Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListViewItem * parent, const GpgME::UserID & userID )
+ : KeyListViewItem( parent, userID.parent() ), mUserID( userID )
{
}
-Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::UserID & userID )
- : KeyListViewItem( tqparent, after, userID.tqparent() ), mUserID( userID )
+Kleo::UserIDKeyListViewItem::UserIDKeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::UserID & userID )
+ : KeyListViewItem( parent, after, userID.parent() ), mUserID( userID )
{
}
void Kleo::UserIDKeyListViewItem::setUserID( const GpgME::UserID & userID ) {
mUserID = userID;
- setKey( userID.tqparent() );
+ setKey( userID.parent() );
}
TQString Kleo::UserIDKeyListViewItem::text( int col ) const {
@@ -640,33 +640,33 @@ void Kleo::UserIDKeyListViewItem::paintCell( TQPainter * p, const TQColorGroup &
//
//
-Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListView * tqparent, const GpgME::UserID::Signature & signature )
- : KeyListViewItem( tqparent, signature.tqparent().tqparent() ), mSignature( signature )
+Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListView * parent, const GpgME::UserID::Signature & signature )
+ : KeyListViewItem( parent, signature.parent().parent() ), mSignature( signature )
{
}
-Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListView * tqparent, KeyListViewItem * after, const GpgME::UserID::Signature & signature )
- : KeyListViewItem( tqparent, after, signature.tqparent().tqparent() ), mSignature( signature )
+Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListView * parent, KeyListViewItem * after, const GpgME::UserID::Signature & signature )
+ : KeyListViewItem( parent, after, signature.parent().parent() ), mSignature( signature )
{
}
-Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListViewItem * tqparent, const GpgME::UserID::Signature & signature )
- : KeyListViewItem( tqparent, signature.tqparent().tqparent() ), mSignature( signature )
+Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListViewItem * parent, const GpgME::UserID::Signature & signature )
+ : KeyListViewItem( parent, signature.parent().parent() ), mSignature( signature )
{
}
-Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListViewItem * tqparent, KeyListViewItem * after, const GpgME::UserID::Signature & signature )
- : KeyListViewItem( tqparent, after, signature.tqparent().tqparent() ), mSignature( signature )
+Kleo::SignatureKeyListViewItem::SignatureKeyListViewItem( KeyListViewItem * parent, KeyListViewItem * after, const GpgME::UserID::Signature & signature )
+ : KeyListViewItem( parent, after, signature.parent().parent() ), mSignature( signature )
{
}
void Kleo::SignatureKeyListViewItem::setSignature( const GpgME::UserID::Signature & signature ) {
mSignature = signature;
- setKey( signature.tqparent().tqparent() );
+ setKey( signature.parent().parent() );
}
TQString Kleo::SignatureKeyListViewItem::text( int col ) const {
@@ -402,7 +402,7 @@ Kleo::KeyListViewItem::~KeyListViewItem() {
delete item;
// better do this here, too, since deletion is top-down and thus
- // we're deleted when our tqparent item is no longer a
+ // we're deleted when our parent item is no longer a
// KeyListViewItem, but a mere TQListViewItem, so our takeItem()
// overload is gone by that time...